@@ -239,7 +239,13 @@ function PMA_fatalError(
         }
 
         // these variables are used in the included file libraries/error.inc.php
-        $error_header = __('Error');
+        //first check if php-mbstring is available
+        if (function_exists('mb_detect_encoding')) {
+            //If present use gettext
+            $error_header = __('Error');
+        } else {
+            $error_header = 'Error';
+        }
         $lang = $GLOBALS['available_languages'][$GLOBALS['lang']][1];
         $dir = $GLOBALS['text_dir'];
 
@@ -712,29 +718,6 @@ function PMA_downloadHeader($filename, $mimetype, $length = 0, $no_cache = true)
     }
 }
 
-/**
- * Checks whether element given by $path exists in $array.
- * $path is a string describing position of an element in an associative array,
- * eg. Servers/1/host refers to $array[Servers][1][host]
- *
- * @param string $path  path in the array
- * @param array  $array the array
- *
- * @return mixed    array element or $default
- */
-function PMA_arrayKeyExists($path, $array)
-{
-    $keys = explode('/', $path);
-    $value =& $array;
-    foreach ($keys as $key) {
-        if (! isset($value[$key])) {
-            return false;
-        }
-        $value =& $value[$key];
-    }
-    return true;
-}
-
 /**
  * Returns value of an element in $array given by $path.
  * $path is a string describing position of an element in an associative array,
@@ -874,12 +857,19 @@ function PMA_isAllowedDomain($url)
         'docs.phpmyadmin.net',
         /* mysql.com domains */
         'dev.mysql.com','bugs.mysql.com',
+        /* drizzle.com domains */
+        'www.drizzle.org',
         /* php.net domains */
         'php.net',
         /* Github domains*/
         'github.com','www.github.com',
         /* Following are doubtful ones. */
-        'www.primebase.com','pbxt.blogspot.com'
+        'www.primebase.com',
+        'pbxt.blogspot.com',
+        'www.percona.com',
+        'mysqldatabaseadministration.blogspot.com',
+        'ronaldbradford.com',
+        'xaprb.com',
     );
     if (in_array(/*overload*/mb_strtolower($domain), $domainWhiteList)) {
         return true;
